#
# spec file for package atkmm
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define base_ver 2.36
%define libname  lib%{name}-2_36-1

Name:           atkmm
Version:        2.36.2
Release:        2.4
Summary:        C++ Binding for the ATK library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later AND GPL-3.0-only
Group:          Development/Libraries/C and C++
URL:            https://www.gtkmm.org/
Source0:        https://download.gnome.org/sources/%{name}/%{base_ver}/%{name}-%{version}.tar.xz

BuildRequires:  c++_compiler
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz
BuildRequires:  meson >= 0.55.0
BuildRequires:  pkgconfig
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(atk) >= 2.33.3
BuildRequires:  pkgconfig(glibmm-2.68)
Recommends:     %{name}-doc = %{version}

%description
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

%package -n %{libname}
Summary:        C++ Binding for the ATK library -- Shared Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n %{libname}
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

This package provides the ATK library's C++'s bindings shared library.

%package devel
Summary:        C++ Binding for the ATK library -- Development Files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{libname} >= %{version}

%description devel
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

This package provides all the necessary files for development with ATK
library's C++ bindings.

%package doc
Summary:        C++ Binding for the ATK library -- Documentation
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Documentation/HTML
Requires:       glibmm2-doc
BuildArch:      noarch

%description doc
atkmm is the C++ binding for the ATK library.
This module is part of the GNOME C++ bindings effort.

This package provides the documentation files for the ATK library's
C++ bindings.

%prep
%autosetup -p1

%build
# NEWS should not be executable
chmod -x NEWS
%meson \
	-Dbuild-documentation=true \
	%{nil}
%meson_build

%install
%meson_install
%fdupes %{buildroot}%{_datadir}

%ldconfig_scriptlets -n %{libname}

%files -n %{libname}
%license COPYING
%doc NEWS
%{_libdir}/libatkmm-%{base_ver}.so.*

%files devel
%{_includedir}/atkmm-%{base_ver}/
%{_libdir}/libatkmm-%{base_ver}.so
%{_libdir}/pkgconfig/atkmm-%{base_ver}.pc
%{_libdir}/atkmm-%{base_ver}/include/
%dir %{_libdir}/atkmm-%{base_ver}
%dir %{_libdir}/atkmm-%{base_ver}/proc
%{_libdir}/atkmm-%{base_ver}/proc/m4/

%files doc
%license COPYING.tools
%doc AUTHORS ChangeLog README.md
%{_datadir}/devhelp/books/atkmm-%{base_ver}/
%{_datadir}/doc/atkmm-%{base_ver}/
# Avoid BuildRequires on devhelp
%dir %{_datadir}/devhelp
%dir %{_datadir}/devhelp/books

%changelog
* Fri Dec 16 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Thu Aug 11 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.36.2:
  + Support building with Visual Studio 2022.
  + Meson build:
  - Specify 'check' option in run_command(). Will be necessary
    with future versions of Meson.
  - Perl is not required by new versions of mm-common.
  - Avoid unnecessary configuration warnings.
  - Require meson >= 0.55.0.
  + Require atk >= 2.33.3. Not a new requirement, but previously
    it was not specified in configure.ac and meson.build.
- Use ldconfig_scriptlets macro for post(un) handling.
- Remove erroneous executable bit from NEWS.
* Tue May 25 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.36.1
  + Only build system related changes
* Sat Dec 19 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.36.0:
  + Object: Add get_object_locale(), get/set_accessible_id(),
    property_accessible_table_caption_object() and
    property_accessible_hypertext_nlinks().
  + Text: Add signal_text_insert() and signal_text_remove().
  + Value: Add signal_value_changed().
  + Hyperlink, Object: Remove deprecated properties
  + Build:
  - Use glibmm-2.68 instead of glibmm-2.60
  - Improve NMake support
  - Use __declspec(dllexport) when building with Visual Studio
    Drop gendef.exe
  - Add Meson support
  - doc/reference/: Update for Doxygen >= 1.8.16
  - Change the ABI to atkmm-2.36
- Drop patches fixed upstream:
  + atkmm-use-glibmm-262.patch
  + atkmm-use-glibmm-264.patch
  + atkmm-use-glibmm-266.patch
- Add meson BuildRequires and macros following upstreams port.
- Bump base_ver and libname (and in baselibs.conf) following
  upstream changes.
- Replace gcc-c++ with generic c++_compiler BuildRequires.
- Replace pkgconfig(glibmm-2.66) with pkgconfig(glibmm-2.68)
  BuildRequires.
- Add doxygen, graphviz and xsltproc BuildRequires, needed now to
  build documentation.
- Drop libtool and mm-common BuildRequires.
* Sun Mar 22 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Add atkmm-use-glibmm-266.patch: Forward port to use new glibmm2.
- Replace pkgconfig(glibmm-2.64) BuildRequires with
  pkgconfig(glibmm-2.66).
* Thu Feb 20 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add atkmm-use-glibmm-264.patch: Forward port to use new glibmm2.
- Replace pkgconfig(glibmm-2.62) BuildRequires with
  pkgconfig(glibmm-2.64).
* Mon Sep  9 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Add atkmm-use-glibmm-262.patch: Forward port to use new glibmm2.
  Following this, add libtool and mm-common BuildRequires and pass
  autogen.sh as the patch touches the buildsystem. Also replace
  pkgconfig(glibmm-2.60) with pkgconfig(glibmm-2.62) BuildRequires.
* Mon Dec  3 2018 bjorn.lie@gmail.com
- Update to version 2.29.1:
  + Build:
  - Require C++17.
  - Replace the Visual Studio project files with MSVC NMake
    project files.
  - Use glibmm-2.60 instead of glibmm-2.56.
  - Change the ABI to atkmm-2.30.
- Replace pkgconfig(glibmm-2.58) with pkgconfig(glibmm-2.60)
  BuildRequires.
- Drop pkgconfig(glibmm-2.60): Fixed upstream. Following this, also
  drop libtool and mm-common as well as autogen.sh call, no longer
  needed.
- Bump soname following upstream changes.
- Drop atkmm-glibmm-bump.patch: Fixed upstream.
* Tue Apr 17 2018 dimstar@opensuse.org
- Export CXXFLAGS="-std=c++17" until upstream catches up. Required,
  as libsigc++-3.0 moved to C++17.
* Sat Mar 31 2018 bjorn.lie@gmail.com
- Add atkmm-glibmm-bump.patch, fix build with new glibmm2.
- Following the above, add libtool and mm-common BuildRequires and
  pass autogen.sh as the patch touches the buildsystem.
- Also replace pkgconfig(glibmm-2.56) with pkgconfig(glibmm-2.58).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Sat Feb 24 2018 luc14n0@linuxmail.org
- Update to version 2.27.1:
  + Change ABI to atkmm-2.28.
- Update '+' in GPL/LGPL License tags to '-or-later' and add GPL
  version 2 and 3 to the preamble to comply with the copyrights.
- Update packages descriptions to show more explictly subpackages'
  content.
- Drop unneeded standard BuildRoot tag declaration: RPM already
  handles this itself.
- Point fdupes to the data directory under the build root instead
  of the build root directly, which is a practice that must be
  avoided.
- Rename shared library subpackage name to libatkmm-2_28-1 to
  follow upstream change.
- Recommends the documentation subpackage.
* Fri Aug 25 2017 zaitor@opensuse.org
- Update to version 2.25.4:
  + Build: Use glibmm-2.56 instead of glibmm-2.54. We have changed
    the ABI name in glibmm.
  + Text: Plug memory leaks in get_text_vfunc() and
    get_selection_vfunc(). These vfuncs shall delete the returned
    character array after it has been copied to a Glib::ustring
    (bgo#783360).
* Sat May 20 2017 zaitor@opensuse.org
- Update to version 2.25.3:
  + Use C++11 enum classes instead of old-style enums, and put some
    enums inside relevant class declarations:
  - Relation: Change RelationType to Relation::Type.
  - Text: Move enums into the class.
  + Build: Windows: Visual Studio builds: Update glibmm ABI
    version.
- Changes from version 2.25.2:
  + Build: Use glibmm-2.54 instead of glibmm-2.52.
  +  (Murray Cumming)
  + Replace uses of Glib::ArrayHandle<> and Glib::SListHandle<>
    with vector.
  + Visual Studio: Require Visual Studio 2017.
* Mon Dec  5 2016 jengelh@inai.de
- Rectify rpm groups.
* Mon Dec  5 2016 dimstar@opensuse.org
- Update to version 2.25.1:
  + This is the first release of the atkmm-2.26 API/ABI.
  + Require C++14.
  + Use glibmm-2.52 instead of glibmm-2.4.
  + Fix silent builds (bgo#768797).
- Rename libatkmm-1_6-1 to libatkmm-2_26-1, following upstreams
  soname change.
- Remove outdated condition for openSUSE 11.2 (make the doc package
  unconditionally noarch).
* Fri Apr 15 2016 idonmez@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon Nov 30 2015 zaitor@opensuse.org
- Update to version 2.24.2:
  + Regenerate with the latest glibmm.
* Wed Sep 30 2015 zaitor@opensuse.org
- Update to version 2.24.1:
  + Regenerate with the latest glibmm.
- Changes from version 2.24.0:
  + MSVC build fixes.
* Fri Sep  4 2015 zaitor@opensuse.org
- Update to version 2.23.3:
  + Rebuilt with latest glibmm, whose gmmproc generates C++ move
    operations.
* Sat Jul 25 2015 zaitor@opensuse.org
- Update to version 2.23.2:
  + Use (and require) C++11.
- Changes from version 2.23.1:
  + Atk:
  - Document: Add get/set_attribute() and deprecate
    get_document() and get_document_type().
  - Component: Deprecate add/remove_focus_handler, get_size() and
    get_position().
  - Add Range.
  - Table:
    . Deprecate get_column/row_at_index().
    . Add a get_at() const version and deprecate get_index_at().
  - Text:
    . Deprecate get_text_before_offset(),
    get_text_after_offset().
    . Add get_string_at_offset(), deprecating other methods for
    it.
  - Value: Deprecate get_minimum/maximum_range() in favour or
    get_range().
  + Build: Update MSVC 2005, 2008 and 2010 Projects: Add "Install"
    Project.
* Mon Apr 29 2013 dimstar@opensuse.org
- Update to version 2.22.7:
  + Remove the use of g_type_init() because it has been deprecated.
* Fri Feb  1 2013 coolo@suse.com
- update license to new format
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Tue Nov 15 2011 vuntz@opensuse.org
- Update to version 2.22.6:
  + Add #includes needed with the latest glibmm.
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
- Add atkmm-devel to baselibs
* Thu Jul  7 2011 vuntz@opensuse.org
- Stop using source service to download the tarball, as Factory
  will move away from this.
* Sat Apr 30 2011 dimstar@opensuse.org
- Update to version 2.22.5:
  + bgo#645669: Install the m4 files even without
  - -enable-maintainer-mode, as with other modules.
- Use source services: download_url and set_version.
* Wed Mar 23 2011 fcrozat@novell.com
- Update to version 2.22.4:
  + Avoid a tarball dependency on mm-common.
- Changes from version 2.22.3:
  + a tarball regeneration due to a changed m4 macro in mm-common.
* Sun Jan  9 2011 vuntz@opensuse.org
- Update to version 2.22.2:
  + Install m4 files needed by recent versions of gtkmm when
    building from git.
* Tue Dec  7 2010 vuntz@opensuse.org
- Update to version 2.22.1:
  + Distribute the GPL in the tarball, in addition to the LGPL,
    because the Windows build uses a GPL builder tool.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 2.22.0:
  + Just increased version to show that it's an API/ABI-stable
    release.
* Fri Aug  6 2010 vuntz@opensuse.org
- Initial package: the code got split from gtkmm2.
